`itwinai <https://pypi.org/project/itwinai/>`_
==============================================

.. toctree::
   :maxdepth: 4

   itwinai.torch.modules
   itwinai.tf.modules

.. toctree::
   :maxdepth: 4

   itwinai.cli
   itwinai.components
   itwinai.distributed
   itwinai.loggers
   itwinai.parser
   itwinai.pipeline
   itwinai.serialization
   itwinai.type
   itwinai.utils
